@@ -142,7 +142,7 @@ void ContainmentInterface::addLauncher(QObject *appletInterface, ContainmentInte
                 return;
             }
 
-            const QStringList &containmentProvides = containment->pluginInfo().property(QStringLiteral("X-Plasma-Provides")).value<QStringList>();
+            const QStringList &containmentProvides = KPluginMetaData::readStringList(containment->pluginMetaData().rawData(), QStringLiteral("X-Plasma-Provides"));
 
             if (containmentProvides.contains(QLatin1String("org.kde.plasma.filemanagement"))) {
                 QQuickItem* gObj = qobject_cast<QQuickItem *>(containment->property("_plasma_graphicObject").value<QObject *>());
