@@ -36,12 +36,20 @@ class GroupSortProxy : public QSortFilterProxyModel
 
 class InvalidAppsFilterProxy : public QSortFilterProxyModel
 {
+    Q_OBJECT
+
     public:
-        explicit InvalidAppsFilterProxy(QAbstractItemModel *sourceModel);
+        explicit InvalidAppsFilterProxy(AbstractModel *parentModel, QAbstractItemModel *sourceModel);
         ~InvalidAppsFilterProxy();
 
     protected:
         bool filterAcceptsRow(int source_row, const QModelIndex & source_parent) const;
+
+    private Q_SLOTS:
+        void connectNewFavoritesModel();
+
+    private:
+        QPointer<AbstractModel> m_parentModel;
 };
 
 class RecentUsageModel : public ForwardingModel
