@@ -88,6 +88,20 @@ void Backend::setToolTipItem(QQuickItem *item)
     }
 }
 
+QQuickWindow *Backend::groupDialog() const
+{
+    return m_groupDialog;
+}
+
+void Backend::setGroupDialog(QQuickWindow *dialog)
+{
+    if (dialog != m_groupDialog) {
+        m_groupDialog = dialog;
+
+        emit groupDialogChanged();
+    }
+}
+
 bool Backend::highlightWindows() const
 {
     return m_highlightWindows;
@@ -142,7 +156,7 @@ QVariantList Backend::jumpListActions(const QUrl &launcherUrl, QObject *parent)
             continue;
         }
 
-        QAction *action = new QAction(this);
+        QAction *action = new QAction(parent);
         action->setText(name);
         action->setIcon(QIcon::fromTheme(actionGroup.readEntry("Icon")));
         action->setProperty("exec", exec);
@@ -204,7 +218,7 @@ QVariantList Backend::recentDocumentActions(const QUrl &launcherUrl, QObject *pa
             continue;
         }
 
-        QAction *action = new QAction(this);
+        QAction *action = new QAction(parent);
         action->setText(url.fileName());
         action->setIcon(QIcon::fromTheme(fileItem.iconName(), QIcon::fromTheme("unknown")));
         action->setProperty("agent", storageId);
@@ -219,7 +233,7 @@ QVariantList Backend::recentDocumentActions(const QUrl &launcherUrl, QObject *pa
     }
 
     if (actionCount > 0) {
-        QAction *action = new QAction(this);
+        QAction *action = new QAction(parent);
         action->setText(i18n("Forget Recent Documents"));
         action->setProperty("agent", storageId);
         connect(action, &QAction::triggered, this, &Backend::handleRecentDocumentAction);
@@ -324,6 +338,10 @@ bool Backend::canPresentWindows() const
 
 void Backend::presentWindows(const QVariant &_winIds)
 {
+    if (!m_taskManagerItem || !m_taskManagerItem->window()) {
+        return;
+    }
+
     QList<WId> winIds;
 
     const QVariantList &_winIdsList = _winIds.toList();
@@ -427,5 +445,9 @@ void Backend::updateWindowHighlight()
         windows.append(m_toolTipItem->window()->winId());
     }
 
+    if (windows.count() && m_groupDialog) {
+        windows.append(m_groupDialog->winId());
+    }
+
     KWindowEffects::highlightWindows(m_panelWinId, windows);
 }
