@@ -26,13 +26,15 @@
 
 #include "ui_kcm_add_layout_dialog.h"
 
+#include <config-keyboard.h>
+
 
 AddLayoutDialog::AddLayoutDialog(const Rules* rules_, Flags* flags_, const QString& model_, bool showLabel, QWidget* parent):
 		QDialog(parent),
 		rules(rules_),
 		flags(flags_),
 		model(model_),
-		selectedLanguage("no_language")
+		selectedLanguage(QStringLiteral("no_language"))
 {
     layoutDialogUi = new Ui_AddLayoutDialog();
     layoutDialogUi->setupUi(this);
@@ -151,7 +153,7 @@ void AddLayoutDialog::accept()
 	selectedLayoutUnit.variant = layoutDialogUi->variantComboBox->itemData(layoutDialogUi->variantComboBox->currentIndex()).toString();
     QString label = layoutDialogUi->labelEdit->text();
 	if( label == selectedLayoutUnit.layout ) {
-		label = "";
+		label = QLatin1String("");
 	}
 	selectedLayoutUnit.setDisplayName( label );
 	selectedLayoutUnit.setShortcut(layoutDialogUi->kkeysequencewidget->keySequence());
