@@ -66,9 +66,9 @@ KCMiscKeyboardWidget::KCMiscKeyboardWidget(QWidget *parent)
   ui.rateSlider->setTickInterval(498);
 
   connect(ui.delay, SIGNAL(valueChanged(int)), this, SLOT(delaySpinboxChanged(int)));
-  connect(ui.delaySlider, SIGNAL(valueChanged(int)), this, SLOT(delaySliderChanged(int)));
+  connect(ui.delaySlider, &QAbstractSlider::valueChanged, this, &KCMiscKeyboardWidget::delaySliderChanged);
   connect(ui.rate, SIGNAL(valueChanged(double)), this, SLOT(rateSpinboxChanged(double)));
-  connect(ui.rateSlider, SIGNAL(valueChanged(int)), this, SLOT(rateSliderChanged(int)));
+  connect(ui.rateSlider, &QAbstractSlider::valueChanged, this, &KCMiscKeyboardWidget::rateSliderChanged);
 
   _numlockButtonGroup = new QButtonGroup(ui.numlockButtonGroup);
   _numlockButtonGroup->addButton(ui.radioButton1, 0);
@@ -124,17 +124,17 @@ void TriStateHelper::setTriState(QButtonGroup* group, TriState state)
 
 void KCMiscKeyboardWidget::load()
 {
-  KConfigGroup config(KSharedConfig::openConfig("kcminputrc", KConfig::NoGlobals), "Keyboard");
+  KConfigGroup config(KSharedConfig::openConfig(QStringLiteral("kcminputrc"), KConfig::NoGlobals), "Keyboard");
 
   ui.delay->blockSignals(true);
   ui.rate->blockSignals(true);
 
   // need to read as string to support old "true/false" parameter
   QString key = config.readEntry("KeyboardRepeating", TriStateHelper::getString(STATE_ON));
-  if( key == "true" || key == TriStateHelper::getString(STATE_ON)) {
+  if( key == QLatin1String("true") || key == TriStateHelper::getString(STATE_ON)) {
 	  keyboardRepeat = STATE_ON;
   }
-  else if( key == "false" || key == TriStateHelper::getString(STATE_OFF)) {
+  else if( key == QLatin1String("false") || key == TriStateHelper::getString(STATE_OFF)) {
 	  keyboardRepeat = STATE_OFF;
   }
   else {
@@ -142,8 +142,8 @@ void KCMiscKeyboardWidget::load()
   }
 
 //  keyboardRepeat = (key ? AutoRepeatModeOn : AutoRepeatModeOff);
-  float delay = config.readEntry( "RepeatDelay", 660 );
-  float rate = config.readEntry( "RepeatRate", 25. );
+  int delay = config.readEntry("RepeatDelay", DEFAULT_REPEAT_DELAY);
+  double rate = config.readEntry("RepeatRate", DEFAULT_REPEAT_RATE);
   setRepeat(keyboardRepeat, delay, rate);
 
   //  setRepeat(kbd.global_auto_repeat, ui.delay->value(), ui.rate->value());
@@ -157,7 +157,7 @@ void KCMiscKeyboardWidget::load()
 
 void KCMiscKeyboardWidget::save()
 {
-  KConfigGroup config(KSharedConfig::openConfig("kcminputrc", KConfig::NoGlobals), "Keyboard");
+  KConfigGroup config(KSharedConfig::openConfig(QStringLiteral("kcminputrc"), KConfig::NoGlobals), "Keyboard");
 
   keyboardRepeat = TriStateHelper::getTriState(_keyboardRepeatButtonGroup);
   numlockState = TriStateHelper::getTriState(_numlockButtonGroup);
@@ -171,7 +171,7 @@ void KCMiscKeyboardWidget::save()
 
 void KCMiscKeyboardWidget::defaults()
 {
-    setRepeat(STATE_ON, 660, 25);
+    setRepeat(STATE_ON, DEFAULT_REPEAT_DELAY, DEFAULT_REPEAT_RATE);
     TriStateHelper::setTriState( _numlockButtonGroup, STATE_UNCHANGED );
     emit changed(true);
 }
